@@ -1,4 +1,4 @@
-## $Id: AllMethod.R 481 2011-04-05 16:32:37Z sluque $
+## $Id: AllMethod.R 511 2012-03-08 17:15:32Z sluque $
 
 ###_ + Show and plot
 
@@ -447,8 +447,13 @@ setMethod("getDiveModel", signature(x="TDRcalibrate", diveNo="missing"),
 ## access only those from certain dives -- simplify if only one
 setMethod("getDiveModel", signature(x="TDRcalibrate", diveNo="numeric"),
           function(x, diveNo) {
-              dm <- x@dive.models[diveNo]
-              if (length(diveNo) == 1L) dm[[1]] else dm
+              dml <- x@dive.models
+              tryCatch({
+                  ok <- diveMove:::.diveMatches(names(dml), diveNo)
+                  diveNo.ok <- diveNo[ok]
+                  dm <- x@dive.models[diveNo.ok]
+                  if (length(diveNo.ok) == 1L) dm[[1]] else dm
+              })
           })
 
 ## Basic diveModel
