@@ -1,8 +1,8 @@
 library(diveMove)
 
-(sealX <- readTDR(system.file(file.path("data", "dives.csv"),
-                              package="diveMove"),
-                  concurrentCols=4:6, speed=TRUE,
+zz <- gzfile(system.file(file.path("data", "dives.csv.gz"),
+                         package="diveMove"), open="r")
+(sealX <- readTDR(zz, concurrentCols=4:6, speed=TRUE,
                   sep=";", na.strings="", as.is=TRUE))
 (dcalib <- calibrateDepth(sealX, dry.thr=3610, zoc.method="offset", offset=3))
 (dcalib <- calibrateDepth(sealX, zoc.method="offset", offset=3,
